@@ -1,6 +1,6 @@
-__version__ = "1.24.4"
+__version__ = "1.24.10"
 
 from .io import get_file
-from .query import get_metadata, ZTFQuery
+from .query import ZTFQuery, get_metadata
 
 # from .skyvision import get_summary_logs
