@@ -236,13 +236,37 @@ def get_filedataframe(filenames):
     return merged
 
 
+def filename_to_kind(filename):
+    """ get the kind given the filename
+    
+    this using buildurl.filename_to_kind()
+
+    Parameters
+    ----------
+    filename: str or list
+        (list of) filename or basename
+
+    Returns
+    -------
+    str or list
+        kind (sci, raw, cal)
+
+    """
+    from .buildurl import filename_to_kind
+    if type(filename) is str:
+        return filename_to_kind(filename)
+    return [filename_to_kind(filename_) for filename_ in filename]
+        
+    
 def parse_filename(filename, as_serie=True):
     """ """
     from .buildurl import parse_filename
 
+    parsed = parse_filename(filename)
     if as_serie:
-        return pandas.Series(parse_filename(filename))
-    return parse_filename(filename)
+        return pandas.Series(parsed)
+    
+    return parsed
 
 
 def download_from_filename(
@@ -869,6 +893,9 @@ def download_url(
         overwrite_ = [overwrite] * len(to_download_urls)
         wait_ = [wait] * len(to_download_urls)
         cutouts_ = [cutouts] * len(to_download_urls)
+        if radec is  None:
+            radec = [None,None]
+        
         ra_ = [radec[0]] * len(to_download_urls)
         dec_ = [radec[1]] * len(to_download_urls)
         cutout_size_ = [cutout_size] * len(to_download_urls)
@@ -899,6 +926,28 @@ def download_url(
                 bar.update(len(to_download_urls))
 
 
+def download_fitsdata(url, cookies=None, **kwargs):
+    """ download a fitsfile and get the first data (nothing stored) 
+    
+    Parameters
+    ----------
+    url: str
+        fits file url.
+
+    cookies: None
+        cookies to download the data. Smart to provide it
+        if already loaded, it takes ~0.5s to acquire.
+
+    **kwargs goes to download_single_url
+    
+    Return
+    ------
+    astropy.HDUList    
+    """
+    
+    out = download_single_url(url, cookies=cookies, **kwargs)
+    return fits.HDUList.fromstring(out.content)
+
 def download_single_url(
     url,
     cutouts=False,
@@ -934,8 +983,7 @@ def download_single_url(
             raise ValueError(
                 "You selected to download cutouts only. Please provide the radec parameter. Default cutout_size: 30 arcsec"
             )
-
-    url += f"?center={radec[0]},{radec[1]}&size={cutout_size}arcsec&gzip=false"
+        url += f"?center={radec[0]},{radec[1]}&size={cutout_size}arcsec&gzip=false"
 
     # = Password and Username
     if cookies is None:
